@@ -53,10 +53,10 @@ typedef float gkick_real;
 
 #define GEONKICK_UNUSED(expr) (void)expr
 
-#define GEONKICK_VERSION 0x020600
+#define GEONKICK_VERSION 0x020700
 #define GEONKICK_NAME "Geonkick"
 #define GEONKICK_APP_NAME "geonkick"
-#define GEOKICK_VERSION_STRING "2.6.0"
+#define GEOKICK_VERSION_STRING "2.7.0"
 
 #ifdef GEONKICK_AUDIO_JACK
 #define GKICK_IS_STANDALONE (1)
@@ -64,6 +64,8 @@ typedef float gkick_real;
 #define GKICK_IS_STANDALONE (0)
 #endif
 
+#define GEONKICK_DEFAULT_SAMPLE_RATE 48000
+
 enum geonkick_error {
   	GEONKICK_OK                    = 0,
 	GEONKICK_ERROR                 = 1,
@@ -138,7 +140,7 @@ enum geonkick_channel_type {
 struct geonkick;
 
 enum geonkick_error
-geonkick_create(struct geonkick **kick);
+geonkick_create(struct geonkick **kick, int sample_rate);
 
 void
 geonkick_free(struct geonkick **kick);
