@@ -33,10 +33,12 @@
 #include <RkButton.h>
 #include <RkProgressBar.h>
 #include <RkContainer.h>
+#include <RkTimer.h>
 
 RK_DECLARE_IMAGE_RC(add_per_button);
 RK_DECLARE_IMAGE_RC(save_kit_button);
 RK_DECLARE_IMAGE_RC(open_kit_button);
+RK_DECLARE_IMAGE_RC(export_kit_button);
 
 KitWidget::KitWidget(GeonkickWidget *parent, KitModel *model)
 	: GeonkickWidget(parent)
@@ -45,7 +47,9 @@ KitWidget::KitWidget(GeonkickWidget *parent, KitModel *model)
         , openKitButton{nullptr}
         , saveKitButton{nullptr}
         , percussionsContainer{new RkContainer(this, Rk::Orientation::Vertical)}
+        , levelersTimer{new RkTimer(this, 30)}
 {
+        RK_ACT_BIND(levelersTimer, timeout, RK_ACT_ARGS(), this, onUpdateLevelers());
         percussionsContainer->setHiddenTakesPlace();
         setSize(parent->size());
 
@@ -99,17 +103,29 @@ KitWidget::KitWidget(GeonkickWidget *parent, KitModel *model)
                     this, showFileDialog(FileDialog::Type::Save));
         saveKitButton->show();
         topContainer->addWidget(saveKitButton);
+
+        auto exportKitButton = new RkButton(this);
+        exportKitButton->setBackgroundColor(background());
+        exportKitButton->setCheckable(true);
+        exportKitButton->setSize(16, 16);
+        exportKitButton->setImage(RkImage(16, 16, RK_IMAGE_RC(export_kit_button)));
+        RK_ACT_BIND(exportKitButton, toggled, RK_ACT_ARGS(bool b),
+                    this, exportKitDialog());
+        exportKitButton->show();
+        topContainer->addWidget(exportKitButton);
+
         percussionsContainer->setHeight(kitContainer->height() - topContainer->height());
 
-        auto kitKeysView = new KitKeysView(this, kitModel);
-        kitKeysView->show();
-        topContainer->addSpace(100 - 3 * 16 - 4 * 5);
-        topContainer->addWidget(kitKeysView);
+        auto kitChannelsView = new KitChannelsView(this, kitModel);
+        kitChannelsView->show();
+        topContainer->addSpace(100 - 4 * 16 - 3 * 5 - 10);
+        topContainer->addWidget(kitChannelsView);
 
         kitContainer->addContainer(topContainer);
         kitContainer->addContainer(percussionsContainer);
 
         updateView();
+        levelersTimer->start();
 }
 
 void KitWidget::updateView()
@@ -161,6 +177,7 @@ void KitWidget::showFileDialog(FileDialog::Type type)
 {
         auto fileDialog = new FileDialog(this, type, type == FileDialog::Type::Open ? "Open Kit" : "Save Kit");
         fileDialog->setFilters({".gkit", ".GKIT"});
+        fileDialog->setHomeDirectory(kitModel->getHomePath());
         if (type == FileDialog::Type::Open) {
                 fileDialog->setCurrentDirectoy(kitModel->workingPath("OpenKit"));
                 RK_ACT_BIND(fileDialog, selectedFile,
@@ -200,15 +217,15 @@ void KitWidget::keyPressEvent(RkKeyEvent *event)
         }
 }
 
-KitKeysView::KitKeysView(KitWidget *parent, KitModel *model)
+KitChannelsView::KitChannelsView(KitWidget *parent, KitModel *model)
                 : GeonkickWidget(parent)
                 , kitModel{model}
-                , keyWidth{30}
-        {
-                setSize(kitModel->keysNumber() * keyWidth, keyWidth);
-        }
+                , channelWidth{30}
+{
+        setSize(kitModel->numberOfChannels() * channelWidth, channelWidth);
+}
 
-void KitKeysView::paintWidget(RkPaintEvent *event)
+void KitChannelsView::paintWidget(RkPaintEvent *event)
 {
         RkImage img(size());
         RkPainter paint(&img);
@@ -221,9 +238,9 @@ void KitKeysView::paintWidget(RkPaintEvent *event)
         font.setSize(12);
         paint.setFont(font);
 
-        auto nKeys = kitModel->keysNumber();
-        for (decltype(nKeys) i = 0; i < nKeys; i++) {
-                auto rect = RkRect(i * keyWidth, 0, keyWidth, keyWidth);
+        auto nChannels = kitModel->numberOfChannels();
+        for (decltype(nChannels) i = 0; i < nChannels; i++) {
+                auto rect = RkRect(i * channelWidth, 0, channelWidth, channelWidth);
                 if (i % 2)
                         paint.fillRect(rect, {60, 60, 60});
                 else
@@ -231,7 +248,7 @@ void KitKeysView::paintWidget(RkPaintEvent *event)
                 RkRect txtRect(rect.left(), (rect.height() - paint.font().size()) / 2,
                                rect.width(), paint.font().size());
                 paint.setPen(pen);
-                paint.drawText(txtRect, kitModel->keyName(i));
+                paint.drawText(txtRect, std::to_string(i + 1));
         }
         RkPainter painter(this);
         painter.drawImage(img, 0, 0);
@@ -241,3 +258,21 @@ KitModel* KitWidget::getModel() const
 {
         return kitModel;
 }
+
+void KitWidget::onUpdateLevelers()
+{
+        for (const auto &per: percussionViewList)
+                per->updateLeveler();
+}
+
+void KitWidget::exportKitDialog()
+{
+        auto fileDialog = new FileDialog(this, FileDialog::Type::Save,  "Export kit to sfz");
+        fileDialog->setFilters({".sfz", ".sfz"});
+        fileDialog->setHomeDirectory(kitModel->getHomePath());       
+        fileDialog->setCurrentDirectoy(kitModel->workingPath("Export/Kit/Sfz"));
+        RK_ACT_BIND(fileDialog, selectedFile,
+                    RK_ACT_ARGS(const std::string &file),
+                    kitModel, doExport(file, KitModel::ExportFormat::Sfz));
+}
+
